@@ -4,22 +4,18 @@
 
 package Exporter::Proxy;
 
-use v5.12;
+use v5.10.0;
 use strict;
 
 use Carp;
 
-use List::Util  qw( first           );
-use Symbol      qw( qualify_to_ref  );
+use Symbol  qw( qualify_to_ref );
 
 ########################################################################
 # package variables
 ########################################################################
 
-our $VERSION    = '0.09_01';
-$VERSION = eval $VERSION;
-
-my $disp_list   = 'DISPATCH_OK';
+our $VERSION    = '0.01';
 
 ########################################################################
 # utility functions
@@ -31,106 +27,56 @@ my $disp_list   = 'DISPATCH_OK';
 
 sub import
 {
-    state $stub = sub{};
-
     # discard this package.
     # left on the stack are assignment operators and 
     # exported names.
 
     shift;
 
-    # use "$source" avoid colliding with '$caller' in the 
-    # exported subs.
+    my @exportz = ();
 
-    my $source  = caller;
-    my @exportz = grep { ! /=/ } @_;
     my %argz
-    = map
+    = do
     {
-        split /=/, $_, 2 
-    }
-    grep /=/, @_;
+        my @argz    = grep /=/, @_;
+        @exportz    = grep { ! ( $_ ~~ @argz ) } @_;
+        
+        map { split /=/ } @argz
+    };
 
     # maybe carp about extraneous arguments here?
 
-    my $disp    = delete $argz{ dispatch    } || '';
-    my $preproc = delete $argz{ prefilter   } || '';
+    my $disp    = delete $argz{ dispatch } || '';
+
+    # avoid colliding with '$caller' in the exported subs.
+
+    my $source  = caller;
 
     # if a dispatcher is being used then it must
-    # be exported. in most cases this will be the
+    # be exported. in many cases this will be the
     # only thing exported.
 
     if( $disp )
     {
-        my $list    = qualify_to_ref $disp_list, $source;
-
-        first { $disp eq $_ } @exportz 
+        $disp ~~ @exportz 
         or push @exportz, $disp;
 
-        unless( $source->can( $disp ) )
+        my $ref = qualify_to_ref $disp, $source;
+
+        undef &{ *$ref };
+
+        *$ref
+        = sub
         {
-            my $sub = qualify_to_ref $disp, $source;
-            my $can = qualify_to_ref $disp_list, $source;
+            my $op      = splice @_, 1, 1;
 
-            if( my $sanity = *{ $can }{ ARRAY } )
-            {
-                *$sub
-                = sub
-                {
-                    my $op      = splice @_, 1, 1;
+            my $handler = $source->can( $op )
+            or croak "Bogus $disp: $source cannot '$op'";
 
-                    first { $op eq $_ } @$sanity
-                    or do
-                    {
-                        local $"    = ' ';
-
-                        confess "Bogus $disp: '$op' not in @$sanity"
-                    };
-
-                    # this could happen if someone plays with
-                    # the symbol table after installing the sub.
-
-                    my $handler = $source->can( $op )
-                    or croak "Bogus $disp: $source cannot '$op'";
-
-                    goto &$handler
-                };
-            }
-            else
-            {
-                *$sub
-                = sub
-                {
-                    my $op      = splice @_, 1, 1;
-
-                    my $handler = $source->can( $op )
-                    or croak "Bogus $disp: $source cannot '$op'";
-
-                    goto &$handler
-                };
-            }
-        }
+            goto &$handler
+        };
     }
 
-    my $pre_handler
-    = do
-    {
-        if( $preproc )
-        {
-            sub
-            {
-                my $handler = $source->can( $preproc )
-                or die "$source cannot '$preproc'\n";
-
-                &$handler
-            }
-        }
-        else
-        {
-            state $stub = sub{}
-        }
-    };
-
     @exportz
     or carp "Oddity: nothing requested for export!";
 
@@ -159,17 +105,11 @@ sub import
         shift;
 
         my $caller  = caller;
-        
-        # allow the caller to pre-process the arguments.
-        # notice this happens *before* ":noexport" is 
-        # processed.
-
-        &$pre_handler;
 
         # empty list => use @exportz.
         # :noexport  => use empty list.
 
-        if( first { ':noexport' eq $_ } @_ )
+        if( ':noexport' ~~ @_ )
         {
             @_  = ();
         }
@@ -185,21 +125,21 @@ sub import
         # resolve these at runtime to account for
         # possible autoloading, etc.
 
-        for my $arg ( @_ )
+        for( @_ )
         {
-            index $arg, ':'
+            index $_, ':'
             or next;
 
-            if( first { $arg eq $_ }  @exportz )
+            if( $_ ~~ @exportz )
             {
-                my $source  = qualify_to_ref $arg, $source;
-                my $install = qualify_to_ref $arg, $caller;
+                my $source  = qualify_to_ref $_, $source;
+                my $install = qualify_to_ref $_, $caller;
 
                 *$install   = *$source;
             }
             else
             {
-                die "Bogus $source: '$arg' not exported";
+                die "Bogus $source: '$_' not exported";
             }
         }
     };
@@ -215,13 +155,14 @@ __END__
 
 =head1 NAME
 
-Exporter::Proxy - Simplified symbol export & proxy dispatch.
+Exporter::Proxy - Simplified symbol export by name with
+optional dispatcher.
 
 =head1 SYNOPSIS
 
     package My::Module;
 
-    use Exporter::Proxy qw( foo Bar );
+    use Export::Proxy qw( foo Bar );
 
     # at this point users of My::Module will get
     # *My::Module::foo and *My::Module::Bar 
@@ -250,7 +191,7 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
     # subroutine, Bar as an array, or foo may 
     # be overloaded with &foo, %foo, @foo, $foo.
 
-    $value ~~ $Bar[0]
+    $value ~~ @Bar
     or croak "Invalid '$value'";
 
     delete $foo{ somekey }
@@ -269,9 +210,9 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
     # than to pollute the caller's namespace with 
     # all of the available methods.
 
-    use Exporter::Proxy qw( dispatch=do_something );
+    use Export::Proxy qw( dispatch=frobnicate );
 
-    # at this point 'do_something' is installed in 
+    # at this point 'frobnicate' is installed in 
     # My::Module. it splices out the second
     # argument, uses My::Module->can( $name ) to
     # check if the module has the service availble
@@ -287,13 +228,13 @@ Exporter::Proxy - Simplified symbol export & proxy dispatch.
 
     my $object  = My::Module->construct;
 
-    $object->do_something( foo => @foo_args );
+    $object->frobnicate( foo => @foo_args );
 
     my @test_these  = $object->exports;
 
     my $test_ref    = $objeect->exports;
 
-    # @test_these will be qw( do_something )
+    # @test_these will be qw( frobnicate )
     # $test_ref will be an arrayref of a 
     # copy of the exported values (i.e., 
     # modifying $test_ref does not affect
@@ -322,9 +263,13 @@ request.
 =item import
 
 The arguments to this are the symbol names to 
-export with an optional "dispatch=<name>" or 
-"import=<name>" for installing the dispatcher 
-and extra import handler.
+export with an optional "dispatch=<name>" for
+installing the dispatcher.
+
+The import extracts the exported symbols, adding
+the dispatcher's name to the list if necessary,
+and then installs import, exports, and the 
+dispathcher as necessary.
 
 =back
 
@@ -334,13 +279,6 @@ and extra import handler.
 
 =item import
 
-Import handles two optional directives: "dispatch"
-and "filter". The former installs a dispatch and
-adds its name to the exports, the latter allows pre-
-processing the arguments to import without having to
-write an entire import sub to override this one
-(see examples below).
-
 With no arguments the import uses the original
 exports list, pushing all of the symbols into
 the caller's space.
@@ -385,7 +323,7 @@ or
 
 returns an array[ref] copy of the exported names.
 
-=item dispatch=... (optional)
+=item dispatcher (optional)
 
 When exporting a large number of symbols is
 problematic, a dispatcher can be installed 
@@ -395,7 +333,7 @@ and does a goto.
 
 Calls to the dispatcher look like:
 
-    $module->$dispatch( $name => @name_argz );
+    $module->$dispatcher( $name => @name_argz );
 
 The dispatcher splices $name off the stack,
 checks that $module->can( $name ) (or $object
@@ -409,7 +347,7 @@ For example:
 
     package Query::Services;
 
-    use Exporter::Proxy qw( dispatch=query );
+    use Export::Proxy qw( dispatch=query );
 
     sub lookup
     {
@@ -437,80 +375,6 @@ allows the caller to:
 
     $object->query( lookup => @lookup_argz );
 
-=item prefilter 
-
-Where present this gets first crack at the stack via
-&$subref. This allows the caller to deal with any 
-extra ":foo" arguments without having to write a
-complete import sub. Since Exporter::Proxy's import
-silently ignores anything with a leading colon (other
-than ":noexport") directives can be handled without 
-haviing to munge the stack.
-
-Normal use of this will be the usuall sorts of side-effects
-handled in import subs like reading config files or installing
-variables. This can also deal with any specialized directives 
-by pushing standard lists of exports onto the stack.
-
-    use Exporter::Proxy qw( prefilter=add_groups bim bam foo bar );
-
-    sub bim{}
-    sub bam{}
-
-    sub foo{}
-    sub bar{}
-
-    sub add_groups
-    {
-        state $groupz =
-        {
-            default => [ qw( bim bam ) ],
-            others  => [ qw( foo bar ) ],
-        };
-
-        for my $i ( 0 .. $#_ )
-        {
-            my ( $name ) = $_[$i] =~ m{^ : (\w+) }x
-            or next;
-
-            my $altz    = $groupz->{ $name }
-            or die "Bogus group: '$name' unknown";
-
-            splice @_, $i, 1, @$altz;
-
-            redo
-        }
-    }
-
-The prefilter can consume or munge the stack as necessary. Whatever
-is left will be treated as names for export.
-
-    use Exporter::Proxy qw( prefilter=read_config bim bam foo bar );
-
-    sub read_config
-    {
-        for my $i ( 0 .. $#_ )
-        {
-            my ( $path ) = $_[$i] =~ m{^ : (\w+) }x
-            or next;
-
-            splice @_, $i, 1;
-
-            -e $path    or die "Missing config: '$path'";
-
-            do_something_with $path;
-
-            redo
-        }
-    }
-
-Aside: In later versions of perl
-
-    while( my ( $i, $val ) = each @_ ){ ... }
-
-makes it easier to get $i and the value.
-
-
 =back
 
 A more general use of this is combining a number of 
@@ -524,13 +388,14 @@ becuase the names only propagate up to My::Query.
 My::Query can even use "if" to limit the number
 of services available (e.g., only packages that
 already have an 'IsSafe' method have the modify 
-calls available).
+calls available.
+
 
 =over 4
 
     package My::Query::Handle;
 
-    use Exporter::Proxy 
+    use Export::Proxy 
     qw
     (
         connect
@@ -546,7 +411,7 @@ calls available).
 
     package My::Query::Lookup
 
-    use Exporter::Proxy
+    use Export::Proxy
     qw
     (
         lookup
@@ -557,7 +422,7 @@ calls available).
 
     package My::Query::Modify
 
-    use Exporter::Proxy
+    use Export::Proxy
     qw
     (
         insert
@@ -573,7 +438,7 @@ calls available).
 
     package My::Query;
 
-    use Exporter::Proxy qw( dispatch=query );
+    use Export::Proxy qw( dispatch=query );
 
     use My::Query::Handle;
     use My::Query::Lookup;
